(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     34261,        837]
NotebookOptionsPosition[     31342,        789]
NotebookOutlinePosition[     31901,        810]
CellTagsIndexPosition[     31858,        807]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fab1a852-1d30-497e-9e87-d4e82e8d00a1"],

Cell["Chapter 5, Section 5.4, Figure 5.12a", "Section",
 CellChangeTimes->{
  3.866003882902865*^9},ExpressionUUID->"c9bc2647-41d8-498b-aa00-\
cab3b6c6ca92"],

Cell["Create a graphics object to denote the central planet.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.866003875793829*^9, 3.8660038786717377`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3d9a934d-30f5-4c45-b03d-a52b529ca765"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cp", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.05", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.890917406138618*^9, 3.890917406144867*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"83c5ab64-f4b0-4494-94f7-e0456273090e"],

Cell[TextData[{
 "We use the same functions, ",
 StyleBox["ksolve", "Input"],
 " and ",
 StyleBox["position", "Input"],
 ", as we used in ",
 StyleBox["Fig.5.9.nb",
  FontWeight->"Bold"],
 ", ",
 StyleBox["Fig.5.10a.nb",
  FontWeight->"Bold"],
 " and ",
 StyleBox["Fig.5.11.nb",
  FontWeight->"Bold"],
 " to solve Kepler's equations and find the position vector as a function of \
mean anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"44e6790d-0db6-4a77-9563-7bf4488d2a88"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ksolve", "[", 
    RowBox[{"ma_", ",", "e_"}], "]"}], ":=", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ea", " ", "-", " ", 
       RowBox[{"e", " ", 
        RowBox[{"Sin", "[", "ea", "]"}]}]}], " ", "==", " ", "ma"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"ea", ",", "ma"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8909174181034317`*^9, 3.8909174181098223`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"15b2581e-1e68-4cbe-a569-da891daa1994"],

Cell[BoxData[
 RowBox[{
  RowBox[{"position", "[", 
   RowBox[{"ma_", ",", "a_", ",", "e_"}], "]"}], ":=", "\n", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"eca", "=", 
     RowBox[{"ea", "/.", 
      RowBox[{"ksolve", "[", 
       RowBox[{"ma", ",", "e"}], "]"}]}]}], ";", "\n", 
    RowBox[{"x", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "eca", "]"}], "-", "e"}], ")"}]}], "]"}]}], ";", 
    " ", 
    RowBox[{"y", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"e", "^", "2"}]}], "]"}], " ", 
       RowBox[{"Sin", "[", "eca", "]"}]}], "]"}]}], ";", "\n", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.8909174292056227`*^9, 3.890917429211701*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"676ccd67-47cd-4b53-852e-4e557ed487a9"],

Cell[TextData[{
 "We will use a list, ",
 StyleBox["rotlist", "Input"],
 ", to store the points we calculate.  First we must set it to be empty."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"040a06bf-71e4-4198-b92b-2c36627ece0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rotlist", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8909174408113813`*^9, 3.890917440817605*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"4e1bcc4a-7fbb-4f96-877a-92fae342eeac"],

Cell[TextData[{
 "We are interested in the ",
 StyleBox["p", "Input"],
 " = 4/3 resonance with unit semi-major axis and an eccentricity, ",
 StyleBox["e", "Input"],
 " = 0.3."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7a867bd5-3015-40c9-b7ad-90d2c2c2306b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p", "=", 
   RowBox[{"4", "/", "3"}]}], ";", " ", 
  RowBox[{"a", "=", "1.0"}], ";", " ", 
  RowBox[{"e", "=", "0.3"}], ";"}]], "Input",
 CellChangeTimes->{{3.890917455837336*^9, 3.890917455847871*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"b2e58052-f984-4f8a-bf5f-f483b35d28cd"],

Cell[TextData[{
 "Set up a loop to calculate and add points (positions at equal time \
intervals) to ",
 StyleBox["rotlist", "Input"],
 ".  Note that we have to go round the orbit three times."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"318afe6d-2686-4ffb-a816-c47d0f41cda2"],

Cell[BoxData[
 RowBox[{"Do", "[", "\n", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"posvec", "=", 
      RowBox[{"position", "[", 
       RowBox[{"t", ",", "a", ",", "e"}], "]"}]}], ";", "\n", 
     RowBox[{"f", "=", 
      RowBox[{"N", "[", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"posvec", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"posvec", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], ";", "\n", 
     RowBox[{"rad", "=", 
      RowBox[{"N", "[", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"posvec", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"posvec", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "]"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"\[Theta]", "=", 
      RowBox[{"p", "*", "t"}]}], ";", "\n", 
     RowBox[{"\[Psi]", "=", 
      RowBox[{"\[Theta]", "-", "f"}]}], ";", "\n", 
     RowBox[{"blip", "=", 
      RowBox[{"N", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"rad", "*", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ",", 
         RowBox[{"rad", "*", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}]}], "}"}], "]"}]}], ";", "\n", 
     
     RowBox[{"AppendTo", "[", 
      RowBox[{"rotlist", ",", "blip"}], "]"}], ";"}], ")"}], ",", "\n", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"6", "Pi"}], ",", 
     RowBox[{"Pi", "/", "10"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.890917469833578*^9, 3.8909174698396482`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"d14e5d7c-e18a-43d6-a1b5-8d27322b0c98"],

Cell["Plot the resulting points.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b4cab0ce-8483-4ed8-92ef-b4a8ba404b3a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"points", "=", "\n", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"rotlist", ",", 
    RowBox[{"AspectRatio", "->", "Automatic"}], ",", " ", "\n", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"PointSize", "[", "0.025", "]"}]}], ",", 
    RowBox[{"Axes", "->", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8909174851180277`*^9, 3.890917485124323*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"d28bd6c3-7c13-437b-8dbc-7755a04da27a"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.025], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVk3tIE1AUxqeLECe2UukhQ7NMC0GpidBaJ8TKHuKYWFqKUek0C6WHpSlC
GJWUYj5Dw6AsDadlmkXpcaQ550yn6KT5aHObM92mm2aWRbl7+6MDl/vH5d57
zvf9vs2nU4Tx9gwGg/93rewJttIDgxa/v5jX900Pez/GZ7BPtqHp4aZXI60G
qH2y4DfZ3I2hkVpfecM0MDP6hdLmT2jY3+ivCDdDeWFAg3NlJ9a6cYOCo+ZA
0pU9IXtajdGZhl03RBZwzDG/MwnbYeuBEDn7rAWeZ/LYrCufYalKF1XoMAcX
Su46vBjVQW4V01hQNgOHcrZZ0geMoJCvlBZ4ZeezkpgWuF59KieNrQT3MZ+h
9iErcJpDgh5drIPoS/duyYLmoe2+37RdSzeOr7MKzDwraN9KFK72I+j4I8Lv
WuAcNMXu81CKNRjJ3VCUu98InON9t706tDhsiZtYtcMAyXli74VsLV795ZYz
5K2F8cHIoJY4DXJUa7TbF9XgP+WUP8oawwges1ShVEOMTb8hVCcqB70SJqA4
jd9380MvamsrmopNOmB5upizMrswLCSsfovOAM/cVU4x3XI0l8vKpAPTUDLa
GRbrNohv1s/kS9eaoLDHJ1xs/wVnAwTBi70m6HWf/b3Uo0dnl9oa7jEjlIha
OOphI54RSTdG86egvrvyhO/yHPIFeat1BRoYX35QmsCeR7tU4WWPxgHosek3
j0YnEWtnoGSPhp7PpNjOsY7eP0juYwF9P4m8j8P0f0fyP1bQ/kykP6yh/TeT
/jGGzvedzIdRdP5QMj+qqD5jRB/MoPopiX741UD0TST6oorq70X0xxTqTyrx
Bw9T/5qIf9hK/RUQf/Ec9d+V+I+TlI8Rwgcmv/6PH+RTvjwIX9hP+dtN+MM7
lM8jhE/8SfmNJ/yiJ+VbRfjGKMo/l/CPYpoPkNnyAXqaH0aRLT9wlOarLd2W
L7DS/L0k+YNgmk9Jhy2f8C+/j8OmxIlN0vd/AIjxHZo=
     "]]}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.3, 1.1502706554090507`}, {-1.2636208815594812`, 
   1.2636208815594812`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8909174856369247`*^9, 3.89091757918953*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"0f6e52d2-0030-4ee1-8be2-028212dd5e12"]
}, Open  ]],

Cell[TextData[{
 "Now go through the same procedure again but with more points in order to \
plot the path in the rotating frame.  First set the contents of ",
 StyleBox["rotlist", "Input"],
 " to be empty."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a54b2599-f22e-4787-bc74-d9571204a196"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rotlist", " ", "=", " ", 
   RowBox[{"{", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.890917497426024*^9, 3.890917497431945*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"83e8f073-28f8-474a-bd46-c111cc099dba"],

Cell["Create the points in a loop ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7b03b63e-9b36-4bd2-9bee-8d83f7f81aae"],

Cell[BoxData[
 RowBox[{"Do", "[", "\n", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"posvec", "=", 
      RowBox[{"position", "[", 
       RowBox[{"t", ",", "a", ",", "e"}], "]"}]}], ";", "\n", 
     RowBox[{"f", "=", 
      RowBox[{"N", "[", 
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"posvec", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"posvec", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], ";", "\n", 
     RowBox[{"rad", "=", 
      RowBox[{"N", "[", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"posvec", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"posvec", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], "]"}], "]"}]}], ";", 
     "\n", 
     RowBox[{"\[Theta]", "=", 
      RowBox[{"p", "*", "t"}]}], ";", "\n", 
     RowBox[{"\[Psi]", "=", 
      RowBox[{"\[Theta]", "-", "f"}]}], ";", "\n", 
     RowBox[{"blip", "=", 
      RowBox[{"N", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"rad", "*", 
          RowBox[{"Cos", "[", "\[Psi]", "]"}]}], ",", 
         RowBox[{"rad", "*", 
          RowBox[{"Sin", "[", "\[Psi]", "]"}]}]}], "}"}], "]"}]}], ";", "\n", 
     
     RowBox[{"AppendTo", "[", 
      RowBox[{"rotlist", ",", "blip"}], "]"}], ";"}], ")"}], ",", "\n", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"6", "Pi"}], ",", 
     RowBox[{"Pi", "/", "40"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8909175104154463`*^9, 3.890917510421337*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"b598836f-5513-4ed1-b4c4-3383ecb68702"],

Cell["... and plot them.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"01cb0c09-620f-4532-b690-83d28fa0684b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"curve", " ", "=", "\n", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"rotlist", ",", 
    RowBox[{"Joined", "->", "True"}], ",", "\n", " ", 
    RowBox[{"AspectRatio", "->", "Automatic"}], ",", " ", 
    RowBox[{"Axes", "->", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8909175235680323`*^9, 3.890917527677401*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"bb7b0420-f6e6-49fc-bbd6-76a1d0d7b08d"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVl3s41Gkbx0UHxZZNSiQ6KNtatZsOku7osCqE3WSW3jRbqLbYXuTYcbaj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      "]]}}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.3, 1.1596060142227878`}, {-1.2661627046742456`, 
   1.2661627046742452`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.890917530687533*^9, 3.890917579632094*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"e0aa5121-4d78-4cdf-9f7d-ab7c421cbf1f"]
}, Open  ]],

Cell["\<\
Finally, display the points and the curve on the same plot.  The is the basis \
of Fig.5.12a.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.866003980913671*^9, 3.866003990799419*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"43834b5f-59c5-4979-850a-1a3f42b89998"],

Cell[BoxData[
 RowBox[{"Rotate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"points", ",", "curve", ",", "cp"}], "]"}], ",", 
   RowBox[{"\[Pi]", "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8909175455078297`*^9, 3.890917545513812*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"4918e4d6-4791-41bd-b51b-3e96c3157d8b"],

Cell[BoxData[
 RotationBox[
  GraphicsBox[{{{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.025], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVk3tIE1AUxqeLECe2UukhQ7NMC0GpidBaJ8TKHuKYWFqKUek0C6WHpSlC
GJWUYj5Dw6AsDadlmkXpcaQ550yn6KT5aHObM92mm2aWRbl7+6MDl/vH5d57
zvf9vs2nU4Tx9gwGg/93rewJttIDgxa/v5jX900Pez/GZ7BPtqHp4aZXI60G
qH2y4DfZ3I2hkVpfecM0MDP6hdLmT2jY3+ivCDdDeWFAg3NlJ9a6cYOCo+ZA
0pU9IXtajdGZhl03RBZwzDG/MwnbYeuBEDn7rAWeZ/LYrCufYalKF1XoMAcX
Su46vBjVQW4V01hQNgOHcrZZ0geMoJCvlBZ4ZeezkpgWuF59KieNrQT3MZ+h
9iErcJpDgh5drIPoS/duyYLmoe2+37RdSzeOr7MKzDwraN9KFK72I+j4I8Lv
WuAcNMXu81CKNRjJ3VCUu98InON9t706tDhsiZtYtcMAyXli74VsLV795ZYz
5K2F8cHIoJY4DXJUa7TbF9XgP+WUP8oawwges1ShVEOMTb8hVCcqB70SJqA4
jd9380MvamsrmopNOmB5upizMrswLCSsfovOAM/cVU4x3XI0l8vKpAPTUDLa
GRbrNohv1s/kS9eaoLDHJ1xs/wVnAwTBi70m6HWf/b3Uo0dnl9oa7jEjlIha
OOphI54RSTdG86egvrvyhO/yHPIFeat1BRoYX35QmsCeR7tU4WWPxgHosek3
j0YnEWtnoGSPhp7PpNjOsY7eP0juYwF9P4m8j8P0f0fyP1bQ/kykP6yh/TeT
/jGGzvedzIdRdP5QMj+qqD5jRB/MoPopiX741UD0TST6oorq70X0xxTqTyrx
Bw9T/5qIf9hK/RUQf/Ec9d+V+I+TlI8Rwgcmv/6PH+RTvjwIX9hP+dtN+MM7
lM8jhE/8SfmNJ/yiJ+VbRfjGKMo/l/CPYpoPkNnyAXqaH0aRLT9wlOarLd2W
L7DS/L0k+YNgmk9Jhy2f8C+/j8OmxIlN0vd/AIjxHZo=
       "]]}, {{}, {}}}, {{}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.009166666666666668], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJxVl3s41Gkbx0UHxZZNSiQ6KNtatZsOku7osCqE3WSW3jRbqLbYXuTYcbaj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        "]]}}, {{}, {}}}, 
    {PointSize[0.05], PointBox[{0, 0}]}},
   Axes->{False, False},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   Method->{
    "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
       Directive[
        RGBColor[0.368417, 0.506779, 0.709798], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.880722, 0.611041, 0.142051], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.922526, 0.385626, 0.209179], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.528488, 0.470624, 0.701351], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.772079, 0.431554, 0.102387], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.363898, 0.618501, 0.782349], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[1, 0.75, 0], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.647624, 0.37816, 0.614037], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.571589, 0.586483, 0.], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.915, 0.3325, 0.2125], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
        
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
        AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
     "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
     "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )}},
   PlotRange->{{-1.3, 1.1502706554090507`}, {-1.2636208815594812`, 
    1.2636208815594812`}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  BoxRotation->1.5707963267948966`]], "Output",
 CellChangeTimes->{3.890917546067795*^9, 3.890917579646761*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"9e1f66b1-bdbe-4a91-88a8-55af3bfb09ce"]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{985, 645},
WindowMargins->{{87, Automatic}, {Automatic, 34}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"a72e5917-6d5a-4506-9fab-0b8ea86e07ff"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"fab1a852-1d30-497e-9e87-d4e82e8d00a1"],
Cell[948, 30, 157, 3, 67, "Section",ExpressionUUID->"c9bc2647-41d8-498b-aa00-cab3b6c6ca92"],
Cell[1108, 35, 248, 4, 49, "Text",ExpressionUUID->"3d9a934d-30f5-4c45-b03d-a52b529ca765"],
Cell[1359, 41, 438, 12, 30, "Input",ExpressionUUID->"83c5ab64-f4b0-4494-94f7-e0456273090e"],
Cell[1800, 55, 517, 19, 76, "Text",ExpressionUUID->"44e6790d-0db6-4a77-9563-7bf4488d2a88"],
Cell[2320, 76, 540, 14, 30, "Input",ExpressionUUID->"15b2581e-1e68-4cbe-a569-da891daa1994"],
Cell[2863, 92, 935, 27, 94, "Input",ExpressionUUID->"676ccd67-47cd-4b53-852e-4e557ed487a9"],
Cell[3801, 121, 267, 7, 53, "Text",ExpressionUUID->"040a06bf-71e4-4198-b92b-2c36627ece0e"],
Cell[4071, 130, 238, 5, 30, "Input",ExpressionUUID->"4e1bcc4a-7fbb-4f96-877a-92fae342eeac"],
Cell[4312, 137, 297, 9, 53, "Text",ExpressionUUID->"7a867bd5-3015-40c9-b7ad-90d2c2c2306b"],
Cell[4612, 148, 315, 7, 30, "Input",ExpressionUUID->"b2e58052-f984-4f8a-bf5f-f483b35d28cd"],
Cell[4930, 157, 315, 8, 76, "Text",ExpressionUUID->"318afe6d-2686-4ffb-a816-c47d0f41cda2"],
Cell[5248, 167, 1680, 47, 199, "Input",ExpressionUUID->"d14e5d7c-e18a-43d6-a1b5-8d27322b0c98"],
Cell[6931, 216, 152, 3, 53, "Text",ExpressionUUID->"b4cab0ce-8483-4ed8-92ef-b4a8ba404b3a"],
Cell[CellGroupData[{
Cell[7108, 223, 455, 9, 73, "Input",ExpressionUUID->"d28bd6c3-7c13-437b-8dbc-7755a04da27a"],
Cell[7566, 234, 4378, 108, 413, "Output",ExpressionUUID->"0f6e52d2-0030-4ee1-8be2-028212dd5e12"]
}, Open  ]],
Cell[11959, 345, 329, 8, 76, "Text",ExpressionUUID->"a54b2599-f22e-4787-bc74-d9571204a196"],
Cell[12291, 355, 246, 5, 30, "Input",ExpressionUUID->"83e8f073-28f8-474a-bd46-c111cc099dba"],
Cell[12540, 362, 157, 3, 53, "Text",ExpressionUUID->"7b03b63e-9b36-4bd2-9bee-8d83f7f81aae"],
Cell[12700, 367, 1680, 47, 199, "Input",ExpressionUUID->"b598836f-5513-4ed1-b4c4-3383ecb68702"],
Cell[14383, 416, 144, 3, 53, "Text",ExpressionUUID->"01cb0c09-620f-4532-b690-83d28fa0684b"],
Cell[CellGroupData[{
Cell[14552, 423, 422, 8, 73, "Input",ExpressionUUID->"bb7b0420-f6e6-49fc-bbd6-76a1d0d7b08d"],
Cell[14977, 433, 7171, 154, 412, "Output",ExpressionUUID->"e0aa5121-4d78-4cdf-9f7d-ab7c421cbf1f"]
}, Open  ]],
Cell[22163, 590, 293, 7, 53, "Text",ExpressionUUID->"43834b5f-59c5-4979-850a-1a3f42b89998"],
Cell[22459, 599, 334, 7, 30, "Input",ExpressionUUID->"4918e4d6-4791-41bd-b51b-3e96c3157d8b"],
Cell[22796, 608, 8542, 179, 379, "Output",ExpressionUUID->"9e1f66b1-bdbe-4a91-88a8-55af3bfb09ce"]
}
]
*)

